#
# spec file for package shotcut
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Find qt version used to build
%define qt5version %(pkg-config --modversion Qt5Core)

%bcond_with    x264

Name:           shotcut
Version:        18.03.06
Release:        lp150.1.1
# This package creates a build time version from the current date and uses it to check
# for updates. See patch1 and prep/build section. For reproducible builds.
%define _vstring %(echo %{version} |tr -d ".")
Summary:        Video and audio editor and creator
License:        GPL-3.0+
Group:          Productivity/Multimedia/Video/Editors and Convertors
Url:            http://www.shotcut.org/
Source:         https://github.com/mltframework/shotcut/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE shotcut-desktopfile.patch davejplater@gmail.com -- Fix icon path
Patch0:         shotcut-desktopfile.patch
# PATCH-FIX-OPENSUSE shotcut-noupdatecheck.patch davejplater@gmail.com -- Disable automatic update check
Patch1:         shotcut-noupdatecheck.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libqt5-qtdeclarative-private-headers-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core) >= 5.5.0
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(Qt5UiTools)
BuildRequires:  pkgconfig(Qt5WebKitWidgets)
BuildRequires:  pkgconfig(Qt5WebSockets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(mlt++)
BuildRequires:  pkgconfig(mlt-framework)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(vpx)
# frei0r-plugins prior to 1.4-7.1 are built against qt4 and cause a segfault on startup.
Requires:       frei0r-plugins >= 1.4-7.1
Requires:       ladspa
Requires:       libmlt6-modules
Requires:       melt
Requires:       qmelt
Recommends:     lame
Requires:       ffmpeg >= 2.7
Requires:       %(rpm -qf $(readlink -qne %{_libdir}/libvpx.so) --qf '%%{NAME} >= %%{VERSION}')
%if %{with x264}
BuildRequires:  pkgconfig(x264)
Requires:       %(rpm -qf $(readlink -qne %{_libdir}/libx264.so) --qf '%%{NAME} >= %%{VERSION}')
%endif
# needed on runtime for the timeline to work see https://forums.opensuse.org/showthread.php/520592-shotcut-video-editor-timeline-blank/page3
Requires:       libQt5Sql5-sqlite
Requires:       libqt5-qtgraphicaleffects >= %{qt5version}
Requires:       libqt5-qtquickcontrols >= %{qt5version}

%description
Shotcut is an audio/video editor. It supports most audio, video and
image formats, as well as image sequences with a wide range of
filters and effects. It's compatible with JACK Audio and Melted
Server, and offers an experimental GPU Processing feature.
Shotcut can test MLT XML files, too.

%lang_package

%prep
%setup -q
echo "Qt5Core = %{qt5version}"
%patch0
%patch1

# Search for executable files
find . \
\( -name \*.html -o -name \*.js \) -type f -executable -exec chmod a-x {} + || :

# Create version.json from current version
echo "{" > version.json
echo " \"version_number\": %{_vstring}02," >> version.json
echo " \"version_string\": \"%{version}.02\"," >> version.json
echo " \"url\": \"https://shotcut.org/blog/new-release-%{_vstring}/\"" >> version.json
echo "}" >> version.json
echo "" >> version.json

%build
export _VSTRING="%{version}.02"
%qmake5 \
	QMAKE_STRIP="" \
	_VSTRING="%{version}.02" \
        PREFIX="%{_prefix}" -Wall -recursive

make %{_smp_mflags} VERBOSE=1

%install
%qmake5_install

install -D icons/%{name}-logo-64.png %{buildroot}/%{_datadir}/pixmaps/%{name}.png

# Install language files
langlist="$PWD/%{name}.lang"
langdir="%{_datadir}/%{name}/translations"
basedir=$(basename "$langdir")
pushd $basedir
	for ts in *.ts; do
		[ -e "$ts" ] || continue
		lupdate-qt5 "$ts" && lrelease-qt5 "$ts"
	done
	for qm in *.qm; do
		[ -e "$qm" ] || continue
		if ! grep -wqs "%dir\ $langdir" "$langlist"; then
			echo "%dir $langdir" >>"$langlist"
		fi
		install -Dm0644 "$qm" "%{buildroot}/$langdir/$qm"
		lang="${qm%.qm}"
		echo "%lang($lang) $langdir/$qm" >>"$langlist"
	done
popd
cp -v version.json %{buildroot}%{_datadir}/%{name}
%suse_update_desktop_file -i %{name}
chmod 0755 %{buildroot}/%{_datadir}/%{name}/qml/export-edl/rebuild.sh
%fdupes -s %{buildroot}/%{_datadir}

%post
%desktop_database_post

%postun
%desktop_database_postun

%files
%defattr(-,root,root)
%doc README.md
%license COPYING
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/applications/%{name}.desktop
%exclude %{_datadir}/%{name}/translations

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Tue Apr 24 2018 davejplater@gmail.com
- Update to bug fix release 18.03.06
- Upstream changes:
  * Fix multiply handled KeyEvent regression in Fix #344 shortcut
  not working with undocked Timeline.Fix multiply handled KeyEvent
  regression in Fix #344 shortcut not working with undocked
  Timeline.
  * Fix added Fade Out Volume shows incorrect on Timeline.
  * Fix track name not editable regression in Fix #344 shortcut not
  working with undocked Timeline.
  * Add Mosaic filter.
* Mon Mar  5 2018 davejplater@gmail.com
- Update to release 18.03
- Upstream changes:
  * Add Estonian translation.
  * Fix existing mask filter loading incorrect values.
  * Fix #500 add transition by trimming may shift a clip.
  * Fix #362 Size filter not using correct decimal symbol.
  * Fix #503 crash setting Video Mode after New.
  * Swap role of Alt+Wheel for timeline scroll.
  * Improve timeline track pad behavior.
  * Fix #497 mouse wheel/trackpad scrolling.
  * Fix #344 shortcut not working with undocked Timeline.
  * Fix #486 JACK transport glitches.
  * Fix #361 JACK client connects itself.
  * Fix #487 split validation off by one frame.
  * Avformat properties improvements.
* Wed Jan  3 2018 davejplater@gmail.com
- Update to 18.01
- Upstream changes:
  * Add a Mask video filter.
  * Add support for size and italics of font.
  * Add Audio Spectrum Visualization filter.
  * Fix duration on image clips with in point > 0.
  * Fix memory leak calling Mlt::Playlist::replace_with_blanks().
  * Fix regression in Fix #474 changing properties of color clip
  changes duration. broke trimmed avformat clips.
  * Fix checkbox on low free space dialog not working.
  * Fix #474 changing properties of color clip changes duration.
  * Fix states for showing convert clip dialog.
  * Fix #431 multi-line text may cause export to hang.
* Sat Dec  9 2017 davejplater@gmail.com
- Update to 17.12 and rebase shotcut-noupdatecheck.patch.
- Upstream changes:
  * Adjust timeline faders with filters in panel.
  * Fix #472 adjust timeline faders when add/rm filters in panel.
  * Fix filter on wrong half after a split shows in transition.
  * Show job percentage as text again.
  * Fix #473 JS error in export EDL on orphan transition.
  * Fix #471 GPU processing not switched when needed by project.
  * Make new strings conform to "anymore."
* Thu Dec  7 2017 dimstar@opensuse.org
- Escape the usage of %%{VERSION} when calling out to rpm.
  RPM 4.14 has %%{VERSION} defined as 'the main packages version'.
* Sat Nov  4 2017 davejplater@gmail.com
- Update to 17.11 and rebase shotcut-noupdatecheck.patch.
- Upstream changes:
  * Allow toggle GPU processing in any Display Method.
  * Remove the frameDisplayed throttle.
  * Reduce free space theshold to 50 GiB.
  * Add Nepali translation.
  * Add warning if the drive for export is low on space.
  * Display warning if file to export is in project.
  * Pause upon changing timeline zoom.
  * Hide the gif format and codec.
  * Fix adding transition changes selection.
  * Fix #411 Ripple All Tracks not fully splitting clips.
  * Fix Add All to Timeline not including filters.
  * Do not adjust Timeline zoom until slider is released.
* Tue Oct  3 2017 davejplater@gmail.com
- Update to 17.10 and rebase shotcut-noupdatecheck.patch.
- Upstream changes:
  * Fixed multi-threaded decoding with FFmpeg v3.2.
  * Added 1080p 59.94 and 60 fps video modes.
  * Added support for NVENC to Export panel.
  * Updated SDL to v2.0
  * Updated FFmpeg to v3.2
* Mon Aug 21 2017 olaf@aepfle.de
- Recommend lame unconditionally
* Sat Aug  5 2017 davejplater@gmail.com
- Update to 17.08 and rebase shotcut-noupdatecheck.patch.
- Upstream changes:
  Add Norwegian Bokmål translation.
  Increase maximum of speed field.
  Fix unlinked files dialog not using folder for next open.
  Add another decimal digit of precision to speed.
  Fix fade in/out on clip-only project.
  Fix #442 all image sequences reported missing.
  Increase maximum Timeline zoom level.
  Prevent O key (set out) from pausing playback.
* Fri Jun  9 2017 davejplater@gmail.com
- Update to 17.06
- Require qmelt created in new package webvfx see boo#1043070.
- Upstream changes:
  Add Hungarian translation.
  Fix #428 unable to make image longer than 10 minutes.
  Pin x264 to version before requiring nasm.
  Update Chinese translation file.
* Mon May  8 2017 jengelh@inai.de
- Trim filler words from description
* Thu May  4 2017 davejplater@gmail.com
- Update to 17.05
- Remove auto update with shotcut-noupdatecheck.patch. This also
  enables reproducible builds.
- Rebase shotcut-desktopfile.patch
- Enable libvpx build.
- Upstream changes:
  Fix #412 disable waveform generation when hidden.
  Fix #406 extension included in EDL reel name.
  Fix #405 JavaScript error in Export EDL.
  Use MLT to determine decimal point. (#416)
* Wed May  3 2017 davejplater@gmail.com
- Update to 17.04
- Fix desktop file with shotcut-desktopfile.patch
- Upstream changes:
  Added Japanese translation.
  Added Turkish translation.
  Fix #399 crash after trying to save empty file.
  Do not include <profile> with internal MLT XML.
  Fix missing period before suggested extension.
* Sun Mar  5 2017 davejplater@gmail.com
- Update to 17.03
- Upstream changes:
  Converted the track toggle buttons to icons.
  Now, you can press Del or Backspace to delete a selected item in
  the Recent panel.
  Playback now pauses at the out point in the Source player. (After
  pause, you can press play again to continue beyond the out point.)
  Some stability improvements.
  Performance boost for Size & Position and Rotate filters on
  multi-CPU systems.
* Mon Feb 20 2017 jengelh@inai.de
- Trim description
- Proper shell quoting and replacement of Useless Use Of Cat
  (ls -1).
* Sun Feb  5 2017 mailaender@opensuse.org
- version update to 17.02
- drop fix-building.patch (included upstream)
  * https://github.com/mltframework/shotcut/pull/331
* Fri Oct 28 2016 adrian@suse.com
- version update to 16.10
- fixing build for qt 5.5: fix-building.patch
* Tue Oct 25 2016 davejplater@gmail.com
- Update version 16.08, the highest version to work with qt-5.5
- Required specific version of frei0r-plugins to prevent segfault
- Upstream changes:
    Added count-down (or up) generator: File > Open Other > Count
    Major performance boost for opaque clips on video tracks higher
    than V1 with track Composite enabled and Blend mode: Over.
  Release 16.07
    Added File > Export Frame…
    Added Remove transition to History by trimming a neighboring
    clip to remove it.
    Fixed version checker.
* Sun Oct 23 2016 wbauer@tmo.at
- Required libqt5-qtgraphicaleffects, this is needed for the
  timeline to work. See :
  https://forums.opensuse.org/showthread.php/520592-shotcut-video-editor-timeline-blank/page3
* Wed Jun 15 2016 avvissu@yandex.by
- Update to 16.06:
  * see: http://www.shotcut.org/bin/view/Shotcut/ReleaseNotes
- Add Requires: libvpx
* Wed May  4 2016 avvissu@yandex.by
- Update to 16.05:
  * see: http://www.shotcut.org/bin/view/Shotcut/ReleaseNotes
- Use %%%%make_jobs and %%%%qmake5_install (see: /etc/rpm/macros.qt5)
* Fri Apr  8 2016 avvissu@yandex.by
- Update to 16.04:
  * see: http://www.shotcut.org/bin/view/Shotcut/ReleaseNotes
* Tue Jan 12 2016 avvissu@yandex.ru
- Update to 16.01:
  * see: http://www.shotcut.org/bin/view/Shotcut/ReleaseNotes
* Fri Dec  4 2015 avvissu@yandex.ru
- Update to 15.12:
  * see: http://www.shotcut.org/bin/view/Shotcut/ReleaseNotes
* Tue Nov 10 2015 avvissu@yandex.ru
- Update to 15.11:
  * see: http://www.shotcut.org/bin/view/Shotcut/ReleaseNotes
- Use Qt5 >= 5.5.0
- Add BuildRequires: libqt5-qtdeclarative-private-headers-devel
- Use %%%%qmake5 instead of qmake-qt5
- Search for executable files
- Add language packs
* Fri Aug 14 2015 avvissu@yandex.ru
- Update to 15.08:
  * see: http://www.shotcut.org/bin/view/Shotcut/ReleaseNotes
- Add %%BUILD_ORIG macro to build in Packman
- Spec file cleanup
* Sat Nov 30 2013 dap.darkness@gmail.com
- Initial package.
